summaryrefslogtreecommitdiff
path: root/java/util/zip/ZipFile.java
diff options
context:
space:
mode:
Diffstat (limited to 'java/util/zip/ZipFile.java')
-rw-r--r--java/util/zip/ZipFile.java6
1 files changed, 3 insertions, 3 deletions
diff --git a/java/util/zip/ZipFile.java b/java/util/zip/ZipFile.java
index b6bc5414d..50f489fdb 100644
--- a/java/util/zip/ZipFile.java
+++ b/java/util/zip/ZipFile.java
@@ -105,7 +105,7 @@ public class ZipFile implements ZipConstants
public ZipFile(File file) throws ZipException, IOException
{
this.raf = new RandomAccessFile(file, "r");
- this.name = file.getName();
+ this.name = file.getPath();
}
/**
@@ -134,7 +134,7 @@ public class ZipFile implements ZipConstants
("OPEN_DELETE mode not supported yet in java.util.zip.ZipFile");
}
this.raf = new RandomAccessFile(file, "r");
- this.name = file.getName();
+ this.name = file.getPath();
}
/**
@@ -438,7 +438,7 @@ public class ZipFile implements ZipConstants
}
/**
* Returns the name of this zip file.
*/
public String getName()
{
@@ -438,7 +438,7 @@ public class ZipFile implements ZipConstants
}
/**
- * Returns the name of this zip file.
+ * Returns the (path) name of this zip file.
*/
public String getName()